@@ -1053,6 +1053,16 @@ class Event(TendenciBaseModel):
             
         return False
 
+    def speakers(self, **kwargs):
+        """
+        This method can returns the list of speakers associated with an event.
+        Speakers with no name are excluded in the list.
+        """
+
+        speakers = self.speaker_set.exclude(name="").order_by('pk')
+
+        return speakers
+
     def number_of_days(self):
         delta = self.end_dt - self.start_dt
         return delta.days
