@@ -1,7 +1,8 @@
 from django.conf.urls.defaults import patterns, url
 from tendenci.addons.events.feeds import LatestEntriesFeed
 
-urlpatterns = patterns('tendenci.addons.events',
+urlpatterns = patterns(
+    'tendenci.addons.events',
     url(r'^$', 'views.month_redirect', name="events"),
     url(r'^month/$', 'views.month_view', name="event.month"),
     url(r'^today/$', 'views.today_redirect', name="event.today"),
@@ -30,16 +31,16 @@ urlpatterns = patterns('tendenci.addons.events',
     url(r'^(?P<id>\d+)/$', 'views.details', name="event"),
 
     url(r'^(?P<event_id>\d+)/attendees$', 'views.view_attendees', name="event.attendees"),
-    
+
     #delete
     url(r'^speaker/(?P<id>\d+)/delete/$', 'views.delete_speaker', name='event.delete_speaker'),
     url(r'^group_pricing/(?P<id>\d+)/delete/$', 'views.delete_group_pricing', name='event.delete_group_pricing'),
     url(r'^special_pricing/(?P<id>\d+)/delete/$', 'views.delete_special_pricing', name='event.delete_special_pricing'),
 
     # registration confirmation
-    url(r'^(?P<id>\d+)/registrations/(?P<reg8n_id>\d+)/$', 
+    url(r'^(?P<id>\d+)/registrations/(?P<reg8n_id>\d+)/$',
         'views.registration_confirmation', name='event.registration_confirmation'),
-    url(r'^(?P<id>\d+)/registrations/(?P<hash>\w+)/$', 
+    url(r'^(?P<id>\d+)/registrations/(?P<hash>\w+)/$',
         'views.registration_confirmation', name='event.registration_confirmation'),
 
     # month-view(s) / day-view
@@ -52,20 +53,20 @@ urlpatterns = patterns('tendenci.addons.events',
     url(r'^register/(?P<event_id>\d+)/pre/$', 'views.register_pre', name='event.register_pre'),
     url(r'^register/(?P<event_id>\d+)/individual/(?P<pricing_id>\d+)/$', 'views.register', {'individual': True}, name='event.register_individual'),
     url(r'^register/(?P<event_id>\d+)/table/(?P<pricing_id>\d+)/$', 'views.register', {'is_table': True}, name='event.register_table'),
-#    url(r'^(?P<event_id>\d+)/multi-register/$', 'views.register', name='event.register'),
-    url(r'^registration/(?P<reg8n_id>\d+)/edit/$', 'views.registration_edit', 
+
+    url(r'^registration/(?P<reg8n_id>\d+)/edit/$', 'views.registration_edit',
         name="event.registration_edit"),
-    url(r'^registration/(?P<reg8n_id>\d+)/edit/(?P<hash>\w+)/$', 'views.registration_edit', 
+    url(r'^registration/(?P<reg8n_id>\d+)/edit/(?P<hash>\w+)/$', 'views.registration_edit',
         name="event.registration_edit"),
     url(r'^registrant/checkin/', 'views.registrant_check_in', name='event.registrant_check_in'),
 
     # cancel event registration
-    url(r'^(?P<event_id>\d+)/registrants/cancel/(?P<registrant_id>\d+)/$', 
+    url(r'^(?P<event_id>\d+)/registrants/cancel/(?P<registrant_id>\d+)/$',
         'views.cancel_registrant', name='event.cancel_registrant'),
     url(r'^(?P<event_id>\d+)/registrants/cancel/(?P<hash>\w+)/$',
         'views.cancel_registrant', name='event.cancel_registrant'),
 
-    url(r'^(?P<event_id>\d+)/registrations/cancel/(?P<registration_id>\d+)/$', 
+    url(r'^(?P<event_id>\d+)/registrations/cancel/(?P<registration_id>\d+)/$',
         'views.cancel_registration', name='event.cancel_registration'),
     url(r'^(?P<event_id>\d+)/registrations/cancel/(?P<registration_id>\d+)/(?P<hash>\w+)/$',
         'views.cancel_registration', name='event.cancel_registration'),
@@ -77,75 +78,62 @@ urlpatterns = patterns('tendenci.addons.events',
     url(r'^registrants/search/$', 'views.global_registrant_search', name="event.global.registrant.search"),
     url(r'^(?P<event_id>\d+)/registrants/search/$', 'views.registrant_search', name="event.registrant.search"),
 
-    url(r'^(?P<event_id>\d+)/registrants/roster/$', 'views.registrant_roster', name="event.registrant.roster"),
+    url(r'^(?P<event_id>\d+)/registrants/roster/$',
+        'views.registrant_roster',
+        name="event.registrant.roster"),
 
     url(r'^(?P<event_id>\d+)/registrants/roster/paid',
         'views.registrant_roster',
-        {'roster_view':'paid'},
-        name="event.registrant.roster.paid"
-    ),
+        {'roster_view': 'paid'},
+        name="event.registrant.roster.paid"),
     url(r'^(?P<event_id>\d+)/registrants/roster/non-paid',
         'views.registrant_roster',
-        {'roster_view':'non-paid'},
-        name="event.registrant.roster.non_paid"
-    ),
+        {'roster_view': 'non-paid'},
+        name="event.registrant.roster.non_paid"),
     url(r'^(?P<event_id>\d+)/registrants/roster/total',
         'views.registrant_roster',
-        {'roster_view':'total'},
-        name="event.registrant.roster.total"
-    ),
+        {'roster_view': 'total'},
+        name="event.registrant.roster.total"),
 
     # registrant export
     url(r'^(?P<event_id>\d+)/registrants/export/$',
         'views.registrant_export_with_custom',
-        name="event.registrant.export"
-    ),
+        name="event.registrant.export"),
     url(r'^(?P<event_id>\d+)/registrants/export/paid$',
         'views.registrant_export_with_custom',
-        {'roster_view':'paid'},
-        name="event.registrant.export.paid"
-    ),
+        {'roster_view': 'paid'},
+        name="event.registrant.export.paid"),
     url(r'^(?P<event_id>\d+)/registrants/export/non-paid',
         'views.registrant_export_with_custom',
-        {'roster_view':'non-paid'},
-        name="event.registrant.export.non_paid"
-    ),
+        {'roster_view': 'non-paid'},
+        name="event.registrant.export.non_paid"),
     url(r'^(?P<event_id>\d+)/registrants/export/total',
         'views.registrant_export_with_custom',
-        {'roster_view':'total'},
-        name="event.registrant.export.total"
-    ),
-    
-#    # dynamic pricing registration
-#    url(r'^(?P<event_id>\d+)/register/$', 'registration.views.multi_register', name='event.anon_multi_register'),
-#    url(r'^(?P<event_id>\d+)/register/pricing/$', 'registration.views.ajax_pricing', name='event.reg_pricing'),
-#    url(r'^(?P<event_id>\d+)/register/user_status/$', 'registration.views.ajax_user', name='event.reg_user_status'),
-    
+        {'roster_view': 'total'},
+        name="event.registrant.export.total"),
+
     # addons
     url(r'^(?P<event_id>\d+)/addons/$', 'views.list_addons', name='event.list_addons'),
     url(r'^(?P<event_id>\d+)/addons/add/$', 'views.add_addon', name='event.add_addon'),
     url(r'^(?P<event_id>\d+)/addons/(?P<addon_id>\d+)/edit/$', 'views.edit_addon', name='event.edit_addon'),
     url(r'^(?P<event_id>\d+)/addons/(?P<addon_id>\d+)/disable/$', 'views.disable_addon', name='event.disable_addon'),
     url(r'^(?P<event_id>\d+)/addons/(?P<addon_id>\d+)/enable/$', 'views.enable_addon', name='event.enable_addon'),
-    
+
     # pending events
     url(r'^minimal_add/$', 'views.minimal_add', name='event.minimal_add'),
     url(r'^pending/$', 'views.pending', name='event.pending'),
     url(r'^pending/(?P<event_id>\d+)/approve/$', 'views.approve', name='event.approve'),
-    
     url(r'^registrants/(?P<id>\d+)/$', 'views.registrant_details', name="event.registrant"),
-    
+
     # email registrants
     url(r'^message/(?P<event_id>\d+)/$', 'views.message_add', name='event.message'),
-    
+
     # custom registration form preview
-    url(r'^custom_reg_form/preview/(?P<id>\d+)/$', 'views.custom_reg_form_preview', 
-        name='event.custom_reg_form_preview'),
+    url(r'^custom_reg_form/preview/(?P<id>\d+)/$', 'views.custom_reg_form_preview', name='event.custom_reg_form_preview'),
     # custom registration form preview
-    url(r'^custom_reg_form/list/(?P<event_id>\d+)/$', 'views.event_custom_reg_form_list', 
-        name='event.event_custom_reg_form_list'),
-    
+    url(r'^custom_reg_form/list/(?P<event_id>\d+)/$', 'views.event_custom_reg_form_list', name='event.event_custom_reg_form_list'),
+
     # event types, need to be the last in the urls
     url(r'^(?P<type>[\w\-\/]+)/$', 'views.month_view', name='event.month'),
-    
+
 )
