@@ -17,8 +17,8 @@ urlpatterns = patterns('tendenci.apps.profiles.views',
     url(r'^edit_perms/(?P<id>\d+)/$', 'edit_user_perms', name="profile.edit_perms"),
     url(r'^avatar/(?P<id>\d+)/$', 'change_avatar', name="profile.change_avatar"),
     url(r'^delete/(?P<id>\d+)/$', 'delete', name="profile.delete"),
-    url(r'^(?P<username>[+-.\w\d@]+)/$', 'index', name='profile'),
-    url(r'^(?P<username>[+-.\w\d@]+)/groups/edit/$', 'user_groups_edit', name='profile.edit_groups'),
-    url(r'^(?P<username>[+-.\w\d@]+)/groups/(?P<membership_id>\d+)/edit/$', 'user_role_edit', name='profile.edit_role'),
-    url(r'^(?P<username>[+-.\w\d@]+)/memberships/add/$', 'user_membership_add', name='profile.add_membership'),
+    url(r'^(?P<username>[+-.\w\d@\s]+)/$', 'index', name='profile'),
+    url(r'^(?P<username>[+-.\w\d@\s]+)/groups/edit/$', 'user_groups_edit', name='profile.edit_groups'),
+    url(r'^(?P<username>[+-.\w\d@\s]+)/groups/(?P<membership_id>\d+)/edit/$', 'user_role_edit', name='profile.edit_role'),
+    url(r'^(?P<username>[+-.\w\d@\s]+)/memberships/add/$', 'user_membership_add', name='profile.add_membership'),
 )
